summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/base/task.h')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/task.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
index 7140b691..5a486198 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
@@ -61,13 +61,13 @@
// might be working on something as you send it infomration, you may want
// to have a queue in the task.
//
// (3) Finally it helps manage parent tasks and tqchildren. If a parent
// task gets aborted, all the tqchildren tasks are too. The nice thing
// about this, for example, is if you have one parent task that
// represents, say, and Xmpp connection, then you can spawn a whole bunch
// of infinite lifetime child tasks and now worry about cleaning them up.
// When the parent task goes to STATE_DONE, the task engine will make
// sure all those tqchildren are aborted and get deleted.
//
// Notice that Task has a few built-in states, e.g.,
//
@@ -122,7 +122,7 @@ public:
// Called from outside to stop task without any more callbacks
void Abort(bool nowake = false);
// For managing tqchildren
bool AllChildrenDone();
bool AnyChildError();
@@ -153,7 +153,7 @@ protected:
virtual int ProcessStart() = 0;
virtual int ProcessResponse() { return STATE_DONE; }
// for managing tqchildren (if any)
void AddChild(Task * child);
void AbortAllChildren();
@@ -172,9 +172,9 @@ private:
bool child_error_;
unsigned long long start_time_;
// for managing tqchildren
typedef std::set<Task *> ChildSet;
- ChildSet tqchildren_;
+ ChildSet children_;
};
@@ -61,13 +61,13 @@
// to have a queue in the task.
//
-// (3) Finally it helps manage parent tasks and tqchildren. If a parent
-// task gets aborted, all the tqchildren tasks are too. The nice thing
+// (3) Finally it helps manage parent tasks and children. If a parent
+// task gets aborted, all the children tasks are too. The nice thing
// about this, for example, is if you have one parent task that
// represents, say, and Xmpp connection, then you can spawn a whole bunch
@@ -61,13 +61,13 @@
// of infinite lifetime child tasks and now worry about cleaning them up.
// When the parent task goes to STATE_DONE, the task engine will make
-// sure all those tqchildren are aborted and get deleted.
+// sure all those children are aborted and get deleted.
//
// Notice that Task has a few built-in states, e.g.,
@@ -122,7 +122,7 @@ public:
// Called from outside to stop task without any more callbacks
void Abort(bool nowake = false);
- // For managing tqchildren
+ // For managing children
bool AllChildrenDone();
bool AnyChildError();
@@ -153,7 +153,7 @@ protected:
virtual int ProcessStart() = 0;
virtual int ProcessResponse() { return STATE_DONE; }
- // for managing tqchildren (if any)
+ // for managing children (if any)
void AddChild(Task * child);
void AbortAllChildren();
@@ -172,9 +172,9 @@ private:
bool child_error_;
unsigned long long start_time_;
- // for managing tqchildren
+ // for managing children
typedef std::set<Task *> ChildSet;